%global with_debug 1
%global with_bundled 1
%global with_check 0

%if 0%{?with_debug}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%if 0%{?rhel} && ! 0%{?fedora}
%define gobuild(o:) GO111MODULE=off scl enable go-toolset-1.13 -- go build -buildmode pie -compiler gc -tags="rpm_crashtraceback no_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%else
%define gobuild(o:) GO111MODULE=off go build -buildmode pie -compiler gc -tags="rpm_crashtraceback no_openssl ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-} -compressdwarf=false -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**};
%endif

%global provider github
%global provider_tld com
%global project opencontainers
%global repo runc
# https://github.com/opencontainers/runc
%global import_path %{provider}.%{provider_tld}/%{project}/%{repo}
%global git0 https://%{import_path}
%global commit0 e677e8b33930d54b6335ea7db1faab797609c4c6
%global shortcommit0 %(c=%{commit0}; echo ${c:0:7})

Name: %{repo}
Version: 1.0.0
Release: 70.rhaos4.5.git%{shortcommit0}%{?dist}
Summary: CLI for running Open Containers
ExcludeArch: %{ix86}
License: ASL 2.0
URL: https://github.com/projectatomic/runc
Source0: %{url}/archive/%{commit0}/%{name}-%{shortcommit0}.tar.gz
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
%if 0%{?rhel} && ! 0%{?fedora}
BuildRequires: go-toolset-1.13
%else
BuildRequires: golang
%endif
BuildRequires: git
BuildRequires: go-md2man
BuildRequires: libseccomp-devel
Requires: criu
Requires(pre): container-selinux >= 2:2.2-2

%description
The runc command can be used to start containers which are packaged
in accordance with the Open Container Initiative's specifications,
and to manage containers running under runc.

%prep
%autosetup -Sgit -n %{repo}-%{commit0}
sed -i '/\#\!\/bin\/bash/d' contrib/completions/bash/%{name}

%build
mkdir -p GOPATH
pushd GOPATH
    mkdir -p src/%{provider}.%{provider_tld}/%{project}
    ln -s $(dirs +1 -l) src/%{import_path}
popd

pushd GOPATH/src/%{import_path}
export GO111MODULE=off
export GOPATH=$(pwd)/GOPATH
export BUILDTAGS="selinux seccomp"
%gobuild -o %{name} %{import_path}

pushd man
./md2man-all.sh
popd

%install
install -d -p %{buildroot}%{_bindir}
install -p -m 755 %{name} %{buildroot}%{_bindir}

# install man pages
install -d -p %{buildroot}%{_mandir}/man8
install -p -m 644 man/man8/* %{buildroot}%{_mandir}/man8
# https://bugzilla.redhat.com/show_bug.cgi?id=1823374#c17
install -d -p %{buildroot}%{_usr}/lib/sysctl.d
echo "fs.may_detach_mounts=1" > %{buildroot}%{_usr}/lib/sysctl.d/99-containers.conf
# install bash completion
install -d -p %{buildroot}%{_datadir}/bash-completion/completions
install -p -m 0644 contrib/completions/bash/%{name} %{buildroot}%{_datadir}/bash-completion/completions

%check

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%post
%sysctl_apply 99-containers.conf

%files
%license LICENSE
%doc MAINTAINERS_GUIDE.md PRINCIPLES.md README.md CONTRIBUTING.md
%{_bindir}/%{name}
%{_mandir}/man8/%{name}*
%{_usr}/lib/sysctl.d/99-containers.conf
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Mon Jun 15 2020 Peter Hunt <pehunt@redhat.com> - 1.0.0-70.rhaos4.5.gite677e8b
- Resolves: #1843470 write to state.json atomically

* Tue May 12 2020 Lokesh Mandvekar <lsm5@redhat.com> - 1.0.0-69.rhaos4.5.gita70f354
- build from projectatomc/runc branch rhaos-4.5

* Tue May 05 2020 Jindrich Novy <jnovy@redhat.com> - 1.0.0-68.rc10.rhaos4.5
- use the same release as in rhel7

* Mon Apr 20 2020 Jindrich Novy <jnovy@redhat.com> - 1.0.0-68.rc10.rhaos4.5
- add rhaos4.5 tag to release

* Wed Feb 19 2020 Jindrich Novy <jnovy@redhat.com> - 1.0.0-65.rc10.rhaos4.5
- add rhaos4.5 to release
- initial RHAOS 4.5 build
- fix "RHEL 7.8: cleaning up mounts of Kubernetes service account secrets of deleted pods failing"
- Resolves: #1823374
